@@ -5,7 +5,8 @@ from datetime import datetime
 
 from jinja2 import Environment, FileSystemLoader
 
-from .utils import replace_all, replace_ws, retry_get, retry_post
+from .utils import (replace_all, replace_ws, retry_get, retry_post, rm_tags,
+                    rm_ws)
 from .utils.constants import DATETIME_12, WHITESPACE
 
 
